@@ -78,15 +78,20 @@ get_time()
 static int
 get_columns()
 {
+  int   result = 80; /* default */
+
   FILE *cols = popen ("tput cols", "r");
-  char col_buffer[50];
-  fgets (col_buffer, 50, cols);
-  int c = atoi (col_buffer);
-  if (c > 30)
-    return c;
-  else
-    return 80;	/* default */
+  char  col_buffer[50];
+  char *line = fgets (col_buffer, 50, cols);
+  if (line)
+    {
+      int c = atoi (col_buffer);
+      if (c > 30)
+        result = c;
+    }
   fclose (cols);
+
+  return result;
 }
 
 void
@@ -834,6 +839,7 @@ main (gint   argc,
   terminal.init (player.loop, &player);
   g_main_loop_run (player.loop);
   terminal.end();
+  gtk_interface.end();
 
   /* also clean up */
   gst_element_set_state (player.playbin, GST_STATE_NULL);
